==> kbibtex-0.1.1.tar.bz2: kbibtex-0.1.1/src/bibtexentryfield.h <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef BIBTEXENTRYFIELD_H
#define BIBTEXENTRYFIELD_H

#include <qobject.h>

class BibTeXEntryField : public QObject
{
    Q_OBJECT
public:
    enum FieldType {ftAbstract, ftAddress, ftAnnote, ftAuthor, ftBookTitle, ftChapter, ftCrossRef, ftEdition, ftEditor, ftHowPublished, ftInstitution, ftISBN, ftISSN, ftJournal, ftKey, ftMonth, ftNote, ftNumber, ftOrganization, ftPages, ftPublisher, ftSchool, ftSeries, ftTitle, ftType, ftURL, ftVolume, ftYear, ftUnknown};
    enum FieldRequireStatus {frsRequired, frsOptional, frsIgnored};

    BibTeXEntryField( FieldType fieldType, const QString &value, QObject *parent = 0, const char *name = 0 );
    BibTeXEntryField( const QString &key, const QString &value, QObject *parent = 0, const char *name = 0 );
    BibTeXEntryField( BibTeXEntryField* other );
    ~BibTeXEntryField();

    QString value();
    void setValue( const QString& value );
    QString key();
    FieldType fieldType();

    static QString fieldTypeToString( const FieldType fieldType );
    static FieldType fieldTypeFromString( const QString &fieldTypeString );

private:
    FieldType m_fieldType;
    QString m_value;
    QString m_key;

};

#endif

==> kbibtex-0.1.2.tar.bz2: kbibtex-0.1.2/src/bibtexentryfield.h <==
/***************************************************************************
*   Copyright (C) 2004-2005 by Thomas Fischer                             *
*   fischer@unix-ag.uni-kl.de                                             *
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
*   This program is distributed in the hope that it will be useful,       *
*   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
*   GNU General Public License for more details.                          *
*                                                                         *
*   You should have received a copy of the GNU General Public License     *
*   along with this program; if not, write to the                         *
*   Free Software Foundation, Inc.,                                       *
*   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
***************************************************************************/
#ifndef BIBTEXENTRYFIELD_H
#define BIBTEXENTRYFIELD_H

#include <qobject.h>

class BibTeXEntryField : public QObject
{
    Q_OBJECT
public:
    enum FieldType {ftAbstract, ftAddress, ftAnnote, ftAuthor, ftBookTitle, ftChapter, ftCrossRef, ftEdition, ftEditor, ftHowPublished, ftInstitution, ftISBN, ftISSN, ftJournal, ftKey, ftMonth, ftNote, ftNumber, ftOrganization, ftPages, ftPublisher, ftSchool, ftSeries, ftTitle, ftType, ftURL, ftVolume, ftYear, ftUnknown};
    enum FieldRequireStatus {frsRequired, frsOptional, frsIgnored};

    BibTeXEntryField( FieldType fieldType, const QString &value, bool isString = FALSE, QObject *parent = 0, const char *name = 0 );
    BibTeXEntryField( const QString &key, const QString &value, bool isString = FALSE, QObject *parent = 0, const char *name = 0 );
    BibTeXEntryField( BibTeXEntryField* other );
    ~BibTeXEntryField();

    QString value();
    void setValue( const QString& value, bool isString = FALSE );
    QString key();
    FieldType fieldType();
    bool isString();

    static QString fieldTypeToString( const FieldType fieldType );
    static FieldType fieldTypeFromString( const QString &fieldTypeString );

private:
    FieldType m_fieldType;
    QString m_value;
    QString m_key;
    bool m_isString;
};

#endif
